PyRCS
=====

|PyPI| |Python| |License| |Downloads| |DOI|

.. |PyPI| image:: https://img.shields.io/pypi/v/pyrcs?color=important&label=PyPI
   :target: https://pypi.org/project/pyrcs/
.. |Python| image:: https://img.shields.io/pypi/pyversions/pyrcs?color=informational&label=Python
   :target: https://www.python.org/downloads/
.. |License| image:: https://img.shields.io/pypi/l/pyrcs?color=green&label=License
   :target: https://github.com/mikeqfu/pyrcs/blob/master/LICENSE
.. |Downloads| image:: https://img.shields.io/pypi/dm/pyrcs?color=yellow&label=Downloads
   :target: https://pypistats.org/packages/pyrcs
.. |DOI| image:: https://zenodo.org/badge/92501006.svg
   :target: https://zenodo.org/badge/latestdoi/92501006

**Author**: Qian Fu

PyRCS is a web-scraping tool for collecting |Railway Codes|_ used in different UK rail industry systems.

Resources
---------

- `Documentation <https://pyrcs.readthedocs.io/>`_
- `Issue Tracker <https://github.com/mikeqfu/pyrcs/issues>`_

License
-------

PyRCS is licensed under `GNU General Public License v3.0 (GPLv3) <https://github.com/mikeqfu/pyrcs/blob/master/LICENSE>`_.

Acknowledgement
---------------

The development of the PyRCS is mainly built on data from the |Railway Codes|_ website. The author of the package would like to thank the website editor and `all contributors <http://www.railwaycodes.org.uk/misc/acknowledgements.shtm>`_ to the data resources.

.. _Railway Codes: http://www.railwaycodes.org.uk/index.shtml

.. |Railway Codes| replace:: *Railway Codes*
